pub fn list_components() -> Vec<&'static ComponentEntry>Expand description
Return all registered components sorted by stage then priority (for debug).
pub fn list_components() -> Vec<&'static ComponentEntry>Return all registered components sorted by stage then priority (for debug).